pub enum ConnInitMethod {
Listen,
Connect(SocketAddr),
Rendezvous(SocketAddr),
}Expand description
Describes how this SRT entity will connect to the other.
Variants
Listen
Listens on the local socket, expecting there to be a Connect instance that eventually connects to this socket.
This almost certianly menas you should use it with SrtSocketBuilder::local_port,
As otherwise there is no way to know which port it will bind to.
Connect(SocketAddr)
Connect to a listening socket. It expects the listen socket to be on the SocketAddr provided.
Rendezvous(SocketAddr)
Connect to another Rendezvous connection. This is useful if both sides are behind a NAT. The SocketAddr
passed should be the public address and port of the other Rendezvous connection.