Connection

Struct Connection 

pub struct Connection { /* private fields */ }
Handing connection timeout, etc The only events that this entity cares about is when packets are recevied from the remote, and when packets are sent from the remote

Implementations

Source

impl Connection

pub fn new(conn: ConnectionSettings) -> Self

pub fn on_packet(&mut self, now: Instant)

pub fn on_send(&mut self, now: Instant)

pub fn next_action(&mut self, now: Instant) -> ConnectionAction