ConnectionSettings

Struct ConnectionSettings 

pub struct ConnectionSettings {
    pub remote: SocketAddr,
    pub remote_sockid: SocketID,
    pub local_sockid: SocketID,
    pub socket_start_time: Instant,
    pub init_seq_num: SeqNumber,
    pub max_packet_size: u32,
    pub max_flow_size: u32,
    pub tsbpd_latency: Duration,
}

Fields

remote: SocketAddr

The remote socket to send & receive to

remote_sockid: SocketID

The socket id of the UDT entity on the other side

local_sockid: SocketID

The local UDT socket id

socket_start_time: Instant

The time that this socket started at, used to develop timestamps

init_seq_num: SeqNumber

The first sequence number

max_packet_size: u32

The maximum packet size

max_flow_size: u32

The maxiumum flow size

tsbpd_latency: Duration

The TSBPD latency configured by the user. Not necessarily the actual decided on latency, which is the max of both side’s respective latencies.

Implementations

Source

impl ConnectionSettings

pub fn get_timestamp(&self, at: Instant) -> i32

Timestamp in us

pub fn get_timestamp_now(&self) -> i32

Timestamp in us