DataPacket

Struct DataPacket 

pub struct DataPacket {
    pub seq_number: SeqNumber,
    pub message_loc: PacketLocation,
    pub in_order_delivery: bool,
    pub message_number: MsgNumber,
    pub timestamp: TimeStamp,
    pub dest_sockid: SocketID,
    pub payload: Bytes,
}
A UDT packet carrying data

ⓘ
 0                   1                   2                   3
 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |0|                     Packet Sequence Number                  |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |FF |O|                     Message Number                      |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                          Time Stamp                           |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                    Destination Socket ID                      |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+

(from https://tools.ietf.org/html/draft-gg-udt-03)

Fields

seq_number: SeqNumber

The sequence number is packet based, so if packet n has sequence number i, the next would have i + 1 Represented by a 31 bit unsigned integer, so Sequence number is wrapped after it recahed 2^31 - 1

message_loc: PacketLocation

Message location and delivery order Represented by the first two bits in the second row of 4 bytes

in_order_delivery: bool

In order delivery, the third bit in the second row of 4 bytes

message_number: MsgNumber

The message number, is the ID of the message being passed Represented by the final 29 bits of the third row It’s only 29 bits long, so it’s wrapped after 2^29 - 1

timestamp: TimeStamp

The timestamp, relative to when the connection was created.

dest_sockid: SocketID

The dest socket id, used for UDP multiplexing

payload: Bytes

The rest of the packet, the payload

Implementations

Source

impl DataPacket

pub fn parse(buf: &mut impl Buf) -> Result<DataPacket, PacketParseError>

pub fn serialize(&self, into: &mut impl BufMut)