pub struct ConnectionSettings {
pub remote: SocketAddr,
pub remote_sockid: SocketID,
pub local_sockid: SocketID,
pub socket_start_time: Instant,
pub init_seq_num: SeqNumber,
pub max_packet_size: u32,
pub max_flow_size: u32,
pub tsbpd_latency: Duration,
}Fields
remote: SocketAddrThe remote socket to send & receive to
remote_sockid: SocketIDThe socket id of the UDT entity on the other side
local_sockid: SocketIDThe local UDT socket id
socket_start_time: InstantThe time that this socket started at, used to develop timestamps
init_seq_num: SeqNumberThe first sequence number
max_packet_size: u32The maximum packet size
max_flow_size: u32The maxiumum flow size
tsbpd_latency: DurationThe TSBPD latency configured by the user. Not necessarily the actual decided on latency, which is the max of both side’s respective latencies.
Implementations
Sourceimpl ConnectionSettings
impl ConnectionSettings
Sourcepub fn get_timestamp(&self, at: Instant) -> i32
pub fn get_timestamp(&self, at: Instant) -> i32
Timestamp in us
Sourcepub fn get_timestamp_now(&self) -> i32
pub fn get_timestamp_now(&self) -> i32
Timestamp in us